##  Linking Discovered Items to Suggested Fact Sheets
Learn how to link discovered items from your SAP landscape to relevant fact sheets.
To link discovered items, follow these steps:
  1. In the discovery inbox, choose the item that needs to be linked.
A side panel opens with more information about the item, along with fact sheet suggestions.
  2. Review the discovery details in the Overview tab.
Use this information to decide whether to link the item to a fact sheet and where to link it. If needed, find more information on the Details tab.
  3. Under Link Discovery Item to Your Fact Sheet(s), select which of the suggested application, IT component, and provider fact sheets you want to link.
If suitable fact sheets are found, the label Link to existing appears next to the item.
If no suitable fact sheets are found, the label Create & Link appears next to the item.
  4. Choose **Link**.


Reviewing and Linking Discovered Items to Fact Sheets from From the Side Panel
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio63f8ca7f932440f8af1b8658932d0653_LowRes.png)
